@@ -11,12 +11,17 @@ from gantry.curators import globals
 from gantry.curators.models import (
     CreateCuratorRequest,
     CuratorInfo,
+    EnableCuratorRequest,
     UpdateCuratorRequest,
 )
 from gantry.curators.selectors import Selector
 from gantry.dataset.gantry_dataset import GantryDataset
 from gantry.dataset.main import get_dataset
-from gantry.exceptions import ClientNotInitialized
+from gantry.exceptions import (
+    ClientNotInitialized,
+    CuratorNotFoundError,
+    GantryRequestException,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -47,7 +52,18 @@ class CuratorClient:
 
     @typechecked
     def get_all_curators(self, application_name: Optional[str] = None) -> List["Curator"]:
+        """Returns a list of the curators in the organization if no
+        ``application_name`` is passed, and all the curators associated
+        with the provided application if a name is passed.
 
+        Args:
+            application_name (str, optional): defaults to ``None``,
+                application must exist.
+
+        Returns:
+            ``List[Curator]``: A list of the curators either in the
+            organization or for a specific application.
+        """
         res = self._get_all_curator_infos(application_name=application_name)
         return [Curator.from_curator_info(self._api_client, curator_info) for curator_info in res]
 
@@ -84,6 +100,24 @@ class CuratorClient:
         """
         raise NotImplementedError
 
+    @typechecked
+    def enable_curator(
+        self,
+    ) -> "Curator":
+        """
+        Currently, Curators must be enabled using an instance of the Curator class.
+        """
+        raise NotImplementedError
+
+    @typechecked
+    def disable_curator(
+        self,
+    ) -> "Curator":
+        """
+        Currently, Curators must be disabled using an instance of the Curator class.
+        """
+        raise NotImplementedError
+
     def _get_all_curator_infos(self, application_name: Optional[str] = None) -> List["CuratorInfo"]:
         """
         Get all curators associated with an application.
@@ -134,6 +168,7 @@ class Curator:
     selection criteria using a list of selectors, as well as other metadata
     needed to create and manage the creation jobs.
     """
+
     def __init__(
         self,
         api_client: Optional[APIClient] = None,
@@ -208,6 +243,14 @@ class Curator:
         self._created_at = created_at
         self._selectors = [] if selectors is None else selectors
 
+    def __repr__(self) -> str:
+        return (
+            f"Curator(name={self.name!r}, curated_dataset_name={self.curated_dataset_name!r}, "
+            f"application_name={self.application_name!r}, start_on={self.start_on}, "
+            f"curation_interval={self.curation_interval}, "
+            f"curate_past_intervals={self.curate_past_intervals}, selectors={self.selectors})"
+        )
+
     @property
     def id(self) -> uuid.UUID:
         if self._id is None:
@@ -248,9 +291,15 @@ class Curator:
     def selectors(self) -> List[Selector]:
         return self._selectors
 
-    def create(self) -> "Curator":
+    @property
+    def enabled(self) -> bool:
+        """Enabling or disabling must be done via the `.enable()` or `.disable()` methods"""
+        raise NotImplementedError
+
+    def create(self, enable=True) -> "Curator":
         """
-        Creates the Curator.
+        Creates the Curator. By default, the Curator is also enabled upon creation.
+        Use the `enable` parameter to change this
 
         Once created, the Curator will start curating the dataset according to the
         curation_interval. If curate_past_intervals is set to True, it will curate all
@@ -264,11 +313,18 @@ class Curator:
 
         The curated dataset can be accessed using the get_curated_dataset method..
 
+        Args:
+            enable (Optional[bool]): Whether to automatically enable
+                the curator after creation. Defaults to True.
+
         Returns:
             Curator: The created curator.
         """
         create_curator_request = self._form_create_curator_request()
-        return self._create_curator(create_curator_request)
+        result = self._create_curator(create_curator_request)
+        if enable:
+            result.enable()
+        return result
 
     def update(
         self,
@@ -467,3 +523,38 @@ class Curator:
         self._curation_interval = curator_info.curation_interval
         self._selectors = curator_info.selectors
         return self
+
+    def enable(self) -> str:
+        """
+        Enable Curator - Gantry will resume curating data using this Curator.
+        Intervals that have elapsed since the curator was disabled will be backfilled.
+        """
+        payload = EnableCuratorRequest(name=self.name, enable=True)
+        try:
+            res = self._api_client.request(
+                "PATCH",
+                "/api/v1/curator/enable",
+                json=json.loads(payload.json()),
+                raise_for_status=True,
+            )
+        except GantryRequestException as e:
+            raise CuratorNotFoundError(
+                f"Could not enable {self.name}, did you create the curator?"
+            ) from e
+        return res["data"]
+
+    def disable(self) -> str:
+        """Disable Curator - Gantry will stop curating data using this Curator."""
+        payload = EnableCuratorRequest(name=self.name, enable=False)
+        try:
+            res = self._api_client.request(
+                "PATCH",
+                "/api/v1/curator/enable",
+                json=json.loads(payload.json()),
+                raise_for_status=True,
+            )
+        except GantryRequestException as e:
+            raise CuratorNotFoundError(
+                f"Could not disable {self.name}, did you create the curator?"
+            ) from e
+        return res["data"]
