@@ -27,6 +27,11 @@ class UpdateCuratorRequest(BaseModel):
     allow_create_new_dataset: bool = False
 
 
+class EnableCuratorRequest(BaseModel):
+    name: str
+    enable: bool
+
+
 class CuratorInfo(BaseModel):
     id: uuid.UUID
     application_name: str
