@@ -160,68 +160,35 @@ class GantryDataset:
         self._dataset_s3_prefix = dataset_s3_prefix
         self._aws_region = aws_region
 
-    def push_gantry_dataframe(self, gantrydf: GantryDataFrame, filename: str = ""):
+    def list_versions(self) -> List[Dict[str, Any]]:
         """
-        This method will take a GantryDataFrame as input, and save its contents to a new file in
-        a Dataset. [TODO: add ability to specify custom version message]
+        This method will list all the versions of the dataset. Each dataset version is a snapshot
+        of the dataset at a particular point in time. The result will be sorted from latest
+        to earliest.
 
         Example usage:
 
+            >>> import gantry.dataset as gdataset
             >>> dataset = gdataset.get_dataset(dataset_name)
-            >>> os.listdir(workspace + dataset_name)
-            ['.dataset_metadata', 'dataset_config.yaml', 'README.md', 'tabular_manifests']
-            >>> os.listdir(workspace + dataset_name + '/tabular_manifests')
-            []
-            >>> gantrydf = gquery.query(
-            ...   application=application,
-            ...   start_time=start,
-            ...   end_time=end,
-            ...   version="1.1",
-            ... )
-            >>>
-            >>> _ = dataset.push_gantry_dataframe(gantrydf)
-            >>>
-            >>> _ = dataset.pull()
-            >>> os.listdir(workspace + dataset_name + '/tabular_manifests')
-            ['GantryDataAutoSave__4390b343-b802-4add-ab51-f86e53979c73_2023-02-13_12:09_to_2023-02-13_17:09_rows_0_69.csv']
-
-        Args:
-            gantrydf (GantryDataFrame): the GantryDataFrame that needs to be added to the dataset.
-            filename (str): the name to be given to the file with data from the GantryDataFrame.
-        Returns:
-            Latest commit info.
-        """
-        start_time = gantrydf.query_info.start_time
-        end_time = gantrydf.query_info.end_time
-        final_filename = filename
-        if filename == "":
-            final_filename = f"GantryDataAutoSave__{uuid.uuid4()}_{start_time.strftime('%Y-%m-%d_%H:%M')}_to_{end_time.strftime('%Y-%m-%d_%H:%M')}"  # noqa: E501
-        app_node_id = gantrydf.query_info.application_node_id
-        filters = gantrydf.filters
-        tags = gantrydf.tags
-        resp = self._api_client.request(
-            "POST",
-            f"/api/v1/datasets/{self._dataset_id}/raw_data",
-            json={
-                "model_id": app_node_id,
-                "raw_data_query_parameters": {
-                    "filters": filters,
-                    "tags": tags,
-                    "include_join_id": False,
-                    "hidden_columns": None,
-                    "start_time": start_time,
-                    "end_time": end_time,
-                },
-                "raw_data_csv_prefix": final_filename,
-            },
-            raise_for_status=True,
-        )
-        commit_info = resp["data"]
-        return self._prune_commit_info(commit_info)
-
-    def list_versions(self) -> List[Dict[str, Any]]:
-        """
-        List dataset version history
+            >>> dataset.list_versions()
+            [{'version_id': '7f100fca-f080-4daf-82d1-575e34234930',
+              'dataset': 'dataset_name',
+              'message': 'version notes',
+              'created_at': 'Thu, 16 Feb 2023 00:16:33 GMT',
+              'created_by': '04c894c7-a853-4fec-a024-66f5aae07b06',
+              'is_latest_version': True},
+             {'version_id': '300cdb42-a8c9-4b6e-a16d-4f6c925eb25d',
+              'dataset': 'dataset_name',
+              'message': 'version notes',
+              'created_at': 'Thu, 16 Feb 2023 00:16:18 GMT',
+              'created_by': '04c894c7-a853-4fec-a024-66f5aae07b06',
+              'is_latest_version': False},
+             {'version_id': '51e7771d-5ba9-4bdf-ab61-6d6ec9f7e066',
+              'dataset': 'dataset_name',
+              'message': 'initial dataset commit',
+              'created_at': 'Thu, 16 Feb 2023 00:14:34 GMT',
+              'created_by': '04c894c7-a853-4fec-a024-66f5aae07b06',
+              'is_latest_version': False}]
 
         Returns:
             ``List[Dict[str, Any]]``: dataset versions from latest to earliest.
@@ -231,11 +198,97 @@ class GantryDataset:
         )
         return [self._prune_commit_info(commit_info) for commit_info in response["data"]]
 
+    @typechecked
+    @_ensure_not_deleted
+    @_warn_when_local_changes
+    def pull(
+        self, version_id: Optional[Union[str, uuid.UUID]] = None, forced: bool = False
+    ) -> Optional[Dict[str, Any]]:
+        """
+        Pull a spicific version of the dataset from dataset server to local working directory.
+
+        If version ID is provided, this method will pull the specific snapshot of your dataset
+        based on the version id to working directory. If version ID is not provided, this method
+        will pull the latest version. If forced is set to True, any local changes will be discarded.
+        This method will only change the files in your local dataset folder, pull an older version
+        will not affect the version history.
+
+        Example usage:
+
+            >>> import gantry.dataset as gdataset
+            >>> dataset = gdataset.get_dataset(dataset_name)
+            # pull the latest version of your dataset
+            >>> dataset.pull()
+            # pull a specific version of your dataset
+            >>> dataset.pull("b787034a-798b-4bb3-a726-0e197ddb8aff")
+
+
+        Args:
+            version_id (str, optional): target version ID, defaults to ``None`` which will pull the
+                latest version.
+            forced (bool): whether to discard local changes or not when pulling,
+                defaults to ``False``.
+
+        Returns:
+            Optional[Dict[str, Any]]: A dictionary with metadata representing the versioned rolled
+            back to if successful, ``None`` otherwise.
+        """
+        target_commit = (
+            self._get_commit(commit_id=version_id) if version_id else self._get_latest_commit()
+        )
+
+        metadata_version_id = target_commit[constants.METADATA_S3_FILE_VERSION]
+
+        self._download_files(
+            [
+                DatasetFileInfo(
+                    file_name=constants.DATASET_MANIFEST_FILE,
+                    url=self._get_s3_url(constants.DATASET_MANIFEST_FILE),
+                    version_id=metadata_version_id,
+                )
+            ]
+        )
+
+        diff = self._get_diff_for_pull()
+        self._download_files(diff[constants.MODIFIED_FILES])  # Overwrite modified files
+        self._download_files(diff[constants.DELETED_FILES])  # redownload deleted files
+
+        # delete new added files
+        for f in diff[constants.NEW_FILES]:
+            os.remove(self._get_file_path(f.file_name))
+
+        self._update_head(target_commit)
+        if not os.path.exists(self._get_file_path(constants.STASH_FOLDER)):
+            os.mkdir(self._get_file_path(constants.STASH_FOLDER))
+
+        # Create the tabular_manifests and artifact folder
+        (Path(self.workspace) / self.dataset_name / constants.TABULAR_MANIFESTS).resolve().mkdir(
+            parents=True, exist_ok=True
+        )
+
+        (Path(self.workspace) / self.dataset_name / constants.ARTIFACTS).resolve().mkdir(
+            parents=True, exist_ok=True
+        )
+
+        return self._prune_commit_info(target_commit)
+
     @_ensure_dataset_exists_locally
     def get_diff(self) -> Dict[str, List[str]]:
         """
-        Get lists of new, modified, and deleted files in your local
-        working directory.
+        Show the local changes that have not been pushed to the server yet. This method will return
+        a dictionary with three keys: ``new_files``, ``modified_files``, and ``deleted_files``.
+        Each key will have a list of files that have been added, modified, or deleted respectively.
+
+        Example usage:
+
+            >>> import gantry.dataset as gdataset
+            >>> dataset = gdataset.get_dataset(dataset_name)
+            >>> dataset.pull()
+            # make some changes to the dataset
+            >>> dataset.get_diff()
+            {'new_files': ['tabular_manifests/new_file.csv', 'artifacts/image.png'],
+             'modified_files': ['tabular_manifests/modified_file_1.csv'],
+             'deleted_files': ['tabular_manifests/deleted_file.csv']}
 
         Returns:
             ``dict``: a dictionary representing the diff, which looks like this:
@@ -261,9 +314,39 @@ class GantryDataset:
     @_ensure_not_deleted
     def push_version(self, message: str) -> Dict[str, Any]:
         """
-        Create a new version of this dataset that snapshots any new, modified, or deleted
-        files that exist in the local ``workspace``, a directory where a local copy of your
-        dataset lives, and pushes it to Gantry.
+        This method will create a new dataset version in the remote server with a version
+        message. The new version will include all the local changes that have not been pushed.
+        If there are no local changes, this method will return the current version.
+
+        To avoid race conditions, this method will check that the HEAD of the dataset is up to date.
+        If the HEAD is not up to date, this method will raise a ``DatasetHeadOutOfDateException``.
+        In that case you could stash your local change and pull the latest version of the dataset
+        and try again. Check out the documents for ``stash()``, ``pull()`` and ``restore()`` for
+        more details.
+
+        Example usage:
+
+            >>> import gantry.dataset as gdataset
+            >>> dataset = gdataset.get_dataset(dataset_name)
+            >>> dataset.pull()
+            # make some changes to the dataset
+            >>> dataset.get_diff()
+            {'new_files': ['tabular_manifests/new_file.csv', 'artifacts/image.png'],
+            'modified_files': ['tabular_manifests/modified_file_1.csv'],
+            'deleted_files': ['tabular_manifests/deleted_file.csv']}
+            >>> dataset.push_version("new version notes")
+            {'version_id': '09575ee7-0407-44b8-ae88-765a8270b17a',
+            'dataset': 'dataset_name',
+            'message': 'new version notes',
+            'created_at': 'Wed, 15 Feb 2023 22:17:55 GMT',
+            'created_by': '04c894c7-a853-4fec-a024-66f5aae07b06',
+            'is_latest_version': True}
+            # After pushing the changes, the diff should be empty
+            >>> dataset.get_diff()
+            {'new_files':[],
+            'modified_files':[],
+            'deleted_files':[]}
+
 
         Args:
             message (str): a non-empty string representing a message to associate with
@@ -339,6 +422,69 @@ class GantryDataset:
 
         return self._prune_commit_info(commit_info)
 
+    def push_gantry_dataframe(self, gantrydf: GantryDataFrame, filename: str = ""):
+        """
+        This method will take a GantryDataFrame as input, and save its contents to a new file in
+        your dataset's ``tabular_manifests`` folder, and create a new version. Note that all these
+        operations happen in the remote server, if you have your dataset checked out locally,
+        please make sure you call ``pull()`` after this operation to get the latest data.
+
+        Example usage:
+
+            >>> import gantry.dataset as gdataset
+            >>> dataset = gdataset.get_dataset(dataset_name)
+            >>> dataset.pull()
+            >>> os.listdir(workspace + dataset_name)
+            ['.dataset_metadata', 'dataset_config.yaml', 'README.md', 'tabular_manifests']
+            >>> os.listdir(workspace + dataset_name + '/tabular_manifests')
+            []
+            >>> gantrydf = gquery.query(
+            ...   application=application,
+            ...   start_time=start,
+            ...   end_time=end,
+            ...   version="1.1",
+            ... )
+            >>>
+            >>> _ = dataset.push_gantry_dataframe(gantrydf)
+            >>>
+            >>> _ = dataset.pull()
+            >>> os.listdir(workspace + dataset_name + '/tabular_manifests')
+            ['GantryDataAutoSave__4390b343-b802-4add-ab51-f86e53979c73_2023-02-13_12:09_to_2023-02-13_17:09_rows_0_69.csv']
+
+        Args:
+            gantrydf (GantryDataFrame): the GantryDataFrame that needs to be added to the dataset.
+            filename (str): the name to be given to the file with data from the GantryDataFrame.
+        Returns:
+            Latest commit info.
+        """
+        start_time = gantrydf.query_info.start_time
+        end_time = gantrydf.query_info.end_time
+        final_filename = filename
+        if filename == "":
+            final_filename = f"GantryDataAutoSave__{uuid.uuid4()}_{start_time.strftime('%Y-%m-%d_%H:%M')}_to_{end_time.strftime('%Y-%m-%d_%H:%M')}"  # noqa: E501
+        app_node_id = gantrydf.query_info.application_node_id
+        filters = gantrydf.filters
+        tags = gantrydf.tags
+        resp = self._api_client.request(
+            "POST",
+            f"/api/v1/datasets/{self._dataset_id}/raw_data",
+            json={
+                "model_id": app_node_id,
+                "raw_data_query_parameters": {
+                    "filters": filters,
+                    "tags": tags,
+                    "include_join_id": False,
+                    "hidden_columns": None,
+                    "start_time": start_time,
+                    "end_time": end_time,
+                },
+                "raw_data_csv_prefix": final_filename,
+            },
+            raise_for_status=True,
+        )
+        commit_info = resp["data"]
+        return self._prune_commit_info(commit_info)
+
     @typechecked
     @_ensure_not_deleted
     def push_file(
@@ -349,9 +495,14 @@ class GantryDataset:
         parent_version_id: Optional[Union[uuid.UUID, str]] = None,
     ) -> Dict[str, Any]:
         """
-        Create a new version of this dataset that contains a single new file passed as the
-        ``file`` parameter for this method, and returns information about the newly created
-        version.
+        This method will add a new file to the dataset in Gantry server and create a new version of
+        the dataset. With this method you can easily add new files to the dataset without having to
+        pull the dataset locally. If you have your dataset checked out locally, please make sure you
+        call ``pull()`` after this operation to get the latest data. The difference between this
+        method and ``push_tabular_file()`` is that this method can handle both tabular and
+        non-tabular files. If you are uploading a tabular file, please use ``push_tabular_file()``
+        instead.
+
 
         Args:
             file (IO): the file to be uploaded
@@ -382,9 +533,28 @@ class GantryDataset:
         parent_version_id: Optional[Union[uuid.UUID, str]] = None,
     ) -> Dict[str, Any]:
         """
-        Create a new version of this dataset that contains a single new CSV file passed as the
-        ``file`` parameter for this method, and returns information about the newly created
-        version. The filename must be postfixed with ``.csv``.
+        This method will add a tabular file to the dataset's ``tabular_manifests`` folder and create
+        a new version of the dataset on dataset server. With this method you can easily add new
+        tabular files to an existing dataset without having to pull the dataset locally. If you
+        have your dataset checked out locally, please make sure you call ``pull()`` after this
+        operation to get the latest data. If you are trying to add a non-tabular file, please
+        use ``push_file()`` instead. Note: the tabular filename must be postfixed with ``.csv``.
+
+        Example usage:
+
+            >>> import gantry.dataset as gdataset
+            >>> dataset = gdataset.get_dataset(dataset_name)
+            >>> dataset.push_tabular_file(
+            ...     open("{file_to_be_added}.csv"),
+            ...     "{dataset_file_name}.csv",
+            ...     "version info"
+            ...    )
+            {'version_id': '2b575ee7-0407-44b8-ae88-765a8270b17a',
+            'dataset': 'dataset_name',
+            'message': 'version info',
+            'created_at': 'Wed, 15 Feb 2023 22:17:55 GMT',
+            'created_by': '04c894c7-a853-4fec-a024-66f5aae07b06',
+            'is_latest_version': True}
 
         Args:
             file (IO): the csv file to be uploaded
@@ -413,19 +583,35 @@ class GantryDataset:
     def push_dataframe(
         self,
         dataframe: pd.DataFrame,
-        csvname: Optional[str] = None,
+        filename: Optional[str] = None,
         message: Optional[str] = None,
         parent_version_id: Optional[Union[uuid.UUID, str]] = None,
     ) -> Dict[str, Any]:
         """
-        Create a new version of this dataset that contains a single new CSV created by calling
-        ``to_csv(tempfile, index=False)`` on the ``pandas.DataFrame`` passed as the ``dataframe``
-        parameter to this function. Optionally override the CSV name which will default to a
-        random hash.
+        Add a dataframe to the dataset's ``tabular_manifests`` folder as a csv file and create a new
+        version of the dataset on the dataset server. With this method you can easily add new a
+        dataframe to an existing dataset without having to pull the dataset locally. If you have
+        your dataset checked out locally, please make sure you call ``pull()`` after this operation.
+
+        Example usage:
+
+            >>> import gantry.dataset as gdataset
+            >>> dataset = gdataset.get_dataset(dataset_name)
+            >>> dataset.push_dataframe(
+            ...     pd.DataFrame({"col1": [1, 2, 3], "col2": [4, 5, 6]}),
+            ...     "dataframe.csv",
+            ...     "version info"
+            ... )
+            {'version_id': 'fa575ee7-0407-44b8-ae88-765a8270b17a',
+            'dataset': 'dataset_name',
+            'message': 'version info',
+            'created_at': 'Wed, 15 Feb 2023 22:17:55 GMT',
+            'created_by': '04c894c7-a853-4fec-a024-66f5aae07b06',
+            'is_latest_version': True}
 
         Args:
             dataframe (pd.DataFrame): the dataframe to be uploaded
-            csvname (str, Optional): the name for the csv that will be uploaded. Defaults to
+            filename (str, Optional): the name for the csv that will be uploaded. Defaults to
                 dataframe-<random-hash>.csv
             message (str, Optional): the version message that will be associated with the
                 upload of the file. Defaults to a generic message if not set
@@ -435,11 +621,11 @@ class GantryDataset:
         Returns:
             ``Dict[str, Any]``: A dictionary with metadata representing the version created.
         """
-        if csvname:
-            if csvname[-4:] == constants.CSV_SUFFIX:
-                name = csvname
+        if filename:
+            if filename[-4:] == constants.CSV_SUFFIX:
+                name = filename
             else:
-                name = f"{csvname}{constants.CSV_SUFFIX}"
+                name = f"{filename}{constants.CSV_SUFFIX}"
         else:
             hash = hashlib.md5(pd.util.hash_pandas_object(dataframe).values).hexdigest()
             name = f"dataframe-{hash}{constants.CSV_SUFFIX}"
@@ -457,8 +643,57 @@ class GantryDataset:
         self, version_id: Union[str, uuid.UUID], forced: bool = False
     ) -> Optional[Dict[str, Any]]:
         """
-        Roll back the dataset to a previous version based on version ID, then pull the target
-        version to the local directory specified in ``workspace``.
+        Rollback the dataset data to a previous version and create a new dataset version based on
+        the target version id. With this method you can easily rollback to any previous version of
+        your dataset and continue working on top of it. Note that to do this, you must have your
+        local dataset folder up to date. Also this method will automatically pull the latest version
+        to local dataset folder after the rollback. If forced is set to True, any local changes
+        will be discarded.
+
+        Example usage:
+
+            >>> import gantry.dataset as gdataset
+            >>> dataset = gdataset.get_dataset(dataset_name)
+            >>> dataset.pull()
+            >>> dataset.list_versions()
+            [{'version_id': 'd6f42bd0-b7a9-4089-88fb-be7cee6d4a83',
+            'dataset': 'dataset_name',
+            'message': 'version info',
+            'created_at': 'Wed, 08 Feb 2023 22:02:02 GMT',
+            'created_by': 'db459d6d-c83b-496d-b659-e48bca971156',
+            'is_latest_version': True},
+            {'version_id': 'b787034a-798b-4bb3-a726-0e197ddb8aff',
+            'dataset': 'dataset_name',
+            'message': 'initial dataset commit',
+            'created_at': 'Wed, 08 Feb 2023 22:00:26 GMT',
+            'created_by': 'db459d6d-c83b-496d-b659-e48bca971156',
+            'is_latest_version': False}]
+            >>> dataset.rollback("b787034a-798b-4bb3-a726-0e197ddb8aff")
+            {'version_id': '23bc4d35-0df2-424c-9156-d5ca105eb4c1',
+            'dataset': 'dataset_name',
+            'message': 'Rollback dataset to version: b787034a-798b-4bb3-a726-0e197ddb8aff',
+            'created_at': 'Thu, 09 Feb 2023 00:36:07 GMT',
+            'created_by': 'db459d6d-c83b-496d-b659-e48bca971156',
+            'is_latest_version': True}
+            >>> dataset.list_versions()
+            [{'version_id': '23bc4d35-0df2-424c-9156-d5ca105eb4c1',
+            'dataset': 'dataset_name',
+            'message': 'Rollback dataset to version: b787034a-798b-4bb3-a726-0e197ddb8aff',
+            'created_at': 'Thu, 09 Feb 2023 00:36:07 GMT',
+            'created_by': 'db459d6d-c83b-496d-b659-e48bca971156',
+            'is_latest_version': True},
+            {'version_id': 'd6f42bd0-b7a9-4089-88fb-be7cee6d4a83',
+            'dataset': 'dataset_name',
+            'message': 'version info',
+            'created_at': 'Wed, 08 Feb 2023 22:02:02 GMT',
+            'created_by': 'db459d6d-c83b-496d-b659-e48bca971156',
+            'is_latest_version': False},
+            {'version_id': 'b787034a-798b-4bb3-a726-0e197ddb8aff',
+            'dataset': 'dataset_name',
+            'message': 'initial dataset commit',
+            'created_at': 'Wed, 08 Feb 2023 22:00:26 GMT',
+            'created_by': 'db459d6d-c83b-496d-b659-e48bca971156',
+            'is_latest_version': False}]
 
         Args:
             version_id (str): ID of the version to rollback to.
@@ -482,72 +717,32 @@ class GantryDataset:
         )
 
         commit_info = resp["data"]
-        self.pull(commit_info["id"], forced=True)
+        self.pull(commit_info["id"], forced=forced)
 
         return self._prune_commit_info(commit_info)
 
-    @typechecked
-    @_ensure_not_deleted
-    @_warn_when_local_changes
-    def pull(
-        self, version_id: Optional[Union[str, uuid.UUID]] = None, forced: bool = False
-    ) -> Optional[Dict[str, Any]]:
-        """
-        Sync local dataset folder based on a version id. If version_id was not provided, will sync
-        based on the latest version. Will not allow a pull if there are local changes, to avoid
-        accidentally losing changes
-
-        Args:
-            version_id (str, optional): target version ID, defaults to ``None`` which will pull the
-                latest version.
-            forced (bool): whether to ignore the presence of any local changes
-
-        Returns:
-            Optional[Dict[str, Any]]: A dictionary with metadata representing the versioned rolled
-            back to if successful, ``None`` otherwise.
-        """
-        target_commit = (
-            self._get_commit(commit_id=version_id) if version_id else self._get_latest_commit()
-        )
-
-        metadata_version_id = target_commit[constants.METADATA_S3_FILE_VERSION]
-
-        self._download_files(
-            [
-                DatasetFileInfo(
-                    file_name=constants.DATASET_MANIFEST_FILE,
-                    url=self._get_s3_url(constants.DATASET_MANIFEST_FILE),
-                    version_id=metadata_version_id,
-                )
-            ]
-        )
-
-        diff = self._get_diff_for_pull()
-        self._download_files(diff[constants.MODIFIED_FILES])  # Overwrite modified files
-        self._download_files(diff[constants.DELETED_FILES])  # redownload deleted files
-
-        # delete new added files
-        for f in diff[constants.NEW_FILES]:
-            os.remove(self._get_file_path(f.file_name))
-
-        self._update_head(target_commit)
-        if not os.path.exists(self._get_file_path(constants.STASH_FOLDER)):
-            os.mkdir(self._get_file_path(constants.STASH_FOLDER))
-
-        # Create the tabular_manifests and artifact folder
-        (Path(self.workspace) / self.dataset_name / constants.TABULAR_MANIFESTS).resolve().mkdir(
-            parents=True, exist_ok=True
-        )
-
-        (Path(self.workspace) / self.dataset_name / constants.ARTIFACTS).resolve().mkdir(
-            parents=True, exist_ok=True
-        )
-
-        return self._prune_commit_info(target_commit)
-
     def stash(self) -> None:
         """
-        Stashes local changes for later use.
+        This method will stash all the changes in your local dataset folder to a temporary folder.
+        You can use this method to save your changes before the ``pull()`` method. Later on you can
+        use the ``restore()`` method to restore your changes. Note that if you run ``stash()``
+        multiple times, the changes will be overwritten and only the latest stash will be kept.
+
+        Example usage:
+
+            >>> import gantry.dataset as gdataset
+            >>> dataset = gdataset.get_dataset(dataset_name)
+            >>> dataset.pull()
+            # make some changes to your dataset
+            >>> dataset.get_diff()
+            {'new_files': ['tabular_manifests/new_file.csv', 'artifacts/image.png'],
+            'modified_files': ['tabular_manifests/modified_file_1.csv'],
+            'deleted_files': ['tabular_manifests/deleted_file.csv']}
+            >>> dataset.stash()
+            >>> dataset.get_diff()
+            {'new_files': [],
+            'modified_files': [],
+            'deleted_files': []}
 
         Returns:
             ``None``
@@ -583,7 +778,30 @@ class GantryDataset:
 
     def restore(self) -> None:
         """
-        Restore changes from local stash.
+        This method will restore the changes from the stash to your local dataset folder. Note that
+        if you have made changes to your local dataset folder after the ``stash()`` method, those
+        changes could be overwritten by this method.
+
+        Example usage:
+
+            >>> import gantry.dataset as gdataset
+            >>> dataset = gdataset.get_dataset(dataset_name)
+            >>> dataset.pull()
+            # make some changes to your local dataset folder
+            >>> dataset.get_diff()
+            {'new_files': ['tabular_manifests/new_file.csv', 'artifacts/image.png'],
+            'modified_files': ['tabular_manifests/modified_file_1.csv'],
+            'deleted_files': ['tabular_manifests/deleted_file.csv']}
+            >>> dataset.stash()
+            >>> dataset.get_diff()
+            {'new_files': [],
+            'modified_files': [],
+            'deleted_files': []}
+            >>> dataset.restore()
+            >>> dataset.get_diff()
+            {'new_files': ['tabular_manifests/new_file.csv', 'artifacts/image.png'],
+            'modified_files': ['tabular_manifests/modified_file_1.csv'],
+            'deleted_files': ['tabular_manifests/deleted_file.csv']}
 
         Returns:
             ``None``
@@ -606,9 +824,14 @@ class GantryDataset:
         for file in diff[constants.DELETED_FILES]:
             os.remove(self._get_file_path(file))
 
-    def delete(self):
+    def delete(self) -> None:
         """
-        Soft delete this dataset.
+        Mark the dataset as deleted. As for now this will only hide dataset from the list_datasets
+        API results, it will not delete the dataset data from the server, we are working on
+        implementing the hard delete feature.
+
+        Returns:
+            ``None``
         """
         self._api_client.request(
             "DELETE",
@@ -911,11 +1134,12 @@ class GantryDataset:
                 presigned_url = presigned_urls[self._get_obj_key(item.url)]
                 download_file_from_url(presigned_url=presigned_url, local_path=Path(local_path))
 
-    def _generate_get_presign_url(self, batch: List[DatasetFileInfo]):
+    def _generate_get_presign_url(self, batch: List[DatasetFileInfo], expiration: int = 3600):
         resp = self._api_client.request(
             "POST",
             f"/api/v1/datasets/{self._dataset_id}/presign/getobject",
             json={
+                "expiration": expiration,
                 "obj_infos": [
                     {
                         constants.OBJ_KEY: self._get_obj_key(item.url),
@@ -980,9 +1204,26 @@ class GantryDataset:
     ):
         """
         This function will pull the dataset tabular files from gantry server and convert it
-        to huggingface dataset. This operation will not change your local dataset folder, it
-        will only load dataset tabular files exist in the version you specified into a
-        huggingface dataset object.
+        to huggingface dataset. This method will not pull data to your local dataset folder, it
+        will only load dataset tabular data from a remote server into a huggingface dataset object.
+        If there is no version_id specified, it will load the latest version of the dataset.
+        If streaming set to True, it will return an IterableDataset or IterableDatasetDict instead
+        of a Dataset or DatasetDict. refer to https://huggingface.co/docs/datasets/stream for more
+        details about streaming.
+
+        Example usage:
+
+        .. code-block:: python
+
+            import gantry.dataset as gdataset
+
+            dataset = gdataset.get_dataset(dataset_name)
+
+            # download your dataset as huggingface dataset
+            hf_dataset = dataset.pull_huggingface_dataset_by_version(version_id="version_id")
+
+            # pull the dataset as IterableDataset with streaming
+            hf_dataset = dataset.pull_huggingface_dataset_by_version(version_id="version_id", streaming=True) # noqa: E501
 
         Args:
             version_id (Optional[str], optional): dataset version id to load. Defaults to latest.
@@ -1007,9 +1248,10 @@ class GantryDataset:
         if not features:
             raise DataSchemaMismatchError()
         training_files = []
+        expiration = 604800 if streaming else 7200  # 7 days if streaming, 2 hours otherwise
         for i in range(0, len(tabular_files), BATCH_SIZE):
             batch = tabular_files[i : i + BATCH_SIZE]
-            presigned_urls = self._generate_get_presign_url(batch=batch)
+            presigned_urls = self._generate_get_presign_url(batch=batch, expiration=expiration)
             training_files.extend(presigned_urls.values())
 
         if not training_files:
@@ -1127,10 +1369,26 @@ class GantryDataset:
         self, hf_dataset_name: Optional[str] = None, streaming: bool = False
     ):
         """
-        Create a huggingface dataset based on the local dataset files
+        This function will convert your local dataset folder to a huggingface dataset. Internally
+        Gantry SDK will create a huggingface load script based on the dataset config and then load
+        the dataset into huggingface pyarrow dataset. If streaming set to True, it will return
+        an IterableDataset or IterableDatasetDict instead of a Dataset or DatasetDict. refer to
+        https://huggingface.co/docs/datasets/stream for more details about streaming.
 
-        This method will create a huggingface load script based on the dataset config and
-        then load the dataset into huggingface pyarrow dataset.
+        Example usage:
+
+        .. code-block:: python
+
+            import gantry.dataset as gdataset
+
+            dataset = gdataset.get_dataset(dataset_name)
+            dataset.pull()
+
+            # load the dataset into huggingface dataset
+            hf_dataset = dataset.get_huggingface_dataset()
+
+            # load the dataset into huggingface dataset with streaming
+            hf_dataset = dataset.get_huggingface_dataset(streaming=True)
 
         Args:
             versoion_id (Optional[str], optional): dataset version id to load. Defaults to latest.
