@@ -439,7 +439,7 @@ class Gantry:
         as_batch: bool = False,
         tags: Optional[Union[Dict[str, str], List[Dict[str, str]]]] = None,
         join_keys: Optional[Union[List[str], pd.Series]] = None,
-        row_tags: Optional[List[Dict[str, str]]] = None,
+        row_tags: Optional[Union[List[Dict[str, str]], pd.DataFrame, pd.Series, np.ndarray]] = None,
         global_tags: Optional[Dict[str, str]] = None,
     ) -> Tuple[Optional[str], List[str]]:
         """
@@ -495,10 +495,9 @@ class Gantry:
                 is a dict of the features for the i-th prediction to be logged.
             ignore_inputs (optional, List[str]): A list of names of input features that should not
                 be monitored.
-            timestamps (optional, Union[List[datetime.datetime], pd.DatetimeIndex,
-                np.array[datetime.datetime]):
-                A list of prediction timestamps. If specified, `timestamps[i]`
-                should be the timestamps for the i-th prediction.
+            timestamps (optional, Union[List[datetime.datetime], pd.DatetimeIndex, np.array[datetime.datetime]):  # noqa: E501
+                A list of prediction timestamps.
+                If specified, `timestamps[i]` should be the timestamps for the i-th prediction.
                 If timestamps = None (default), then the prediction
                 timestamp defaults to the time when `log_records` is called.
             sort_on_timestamp (bool, defaults to True): Works when timestamps are provided.
@@ -519,17 +518,20 @@ class Gantry:
             join_keys  (optional, Union[List[str], pd.Series[str]]): provide keys to identify
                 each record. These keys can be used later to provide feedback. If not provided,
                 a random record key will be generated for each record.
-            row_tags (optional, List[Dict[str, str]]): Specify row level tags. If provided,
-                this parameter should be a list of tags to be applied to each of the records.
-                row_tags[i] will contain the tag to attach to the i-th record. For batch global
-                tags, use the 'global_tags' parameter instead.
+            row_tags (optional, Optional[Union[List[Dict[str, str]], pd.DataFrame, pd.Series, np.ndarray]]): Specify row level tags.
+                If provided, this parameter should be a list of tags to be applied to each of the records.
+                row_tags[i] will contain a dictionary of strings containing the tags to attach to the
+                i-th record. Alternatively, tags may be specified by passing in a DataFrame, Series,
+                or Array, like inputs.
+
+                For batch global tags, use the 'global_tags' parameter instead.
             global_tags (optional, Dict[str, str]): Specify a set of tags that will be attached to
                 all ingested records from this batch. For record specific tags, you can use
                 'row_tags' param.
 
         Returns:
-            A tuple of (batch_id, list[join_keys]): The batch_id will be None if records are not
-                logged as batch. The list of join_keys will be the records keys.
+            Tuple[batch_id, list[join_keys]]: The batch_id will be None if records are not
+            logged as batch. The list of join_keys will be the records keys.
 
         """
         if tags:
@@ -542,6 +544,8 @@ class Gantry:
             inputs = inputs.to_frame()
         if outputs is not None and isinstance(outputs, pd.Series):
             outputs = outputs.to_frame()
+        if row_tags is not None and isinstance(row_tags, pd.Series):
+            row_tags = row_tags.to_frame()
         if feedbacks is not None and isinstance(feedbacks, pd.Series):
             feedbacks = feedbacks.to_frame()
         if join_keys is not None and isinstance(join_keys, pd.Series):
@@ -563,6 +567,9 @@ class Gantry:
             )
 
         sizes = {}
+        if row_tags is not None:
+            row_tags = serializable_value(row_tags)
+            check_type("row_tags", row_tags, List[Dict[str, str]])
 
         if feedbacks_exist:
             feedbacks = serializable_value(feedbacks)
