@@ -1402,6 +1402,42 @@ def test_log_records_preds_and_feedback_series_coerced(
                 {"bar": "bar", "env": "foobar", "baz": "baz"},
             ],
         ),
+        (
+            None,
+            [{"bar": "bar"}, {"bar": "baz"}],
+            None,
+            [
+                {"bar": "bar", "env": "test"},
+                {"bar": "baz", "env": "test"},
+            ],
+        ),
+        (
+            None,
+            np.array([{"bar": "bar"}, {"bar": "baz"}]),
+            None,
+            [
+                {"bar": "bar", "env": "test"},
+                {"bar": "baz", "env": "test"},
+            ],
+        ),
+        (
+            None,
+            pd.Series(["bar", "baz"], name="bar"),
+            None,
+            [
+                {"bar": "bar", "env": "test"},
+                {"bar": "baz", "env": "test"},
+            ],
+        ),
+        (
+            None,
+            pd.DataFrame({"bar": ["bar", "baz"]}),
+            None,
+            [
+                {"bar": "bar", "env": "test"},
+                {"bar": "baz", "env": "test"},
+            ],
+        ),
     ],
 )
 @pytest.mark.parametrize(
@@ -1720,6 +1756,42 @@ def test_log_records_preds_and_feedback_wrong_join_keys(
                 {"bar": "bar", "env": "foobar", "baz": "baz"},
             ],
         ),
+        (
+            None,
+            [{"bar": "bar"}, {"bar": "baz"}],
+            None,
+            [
+                {"bar": "bar", "env": "test"},
+                {"bar": "baz", "env": "test"},
+            ],
+        ),
+        (
+            None,
+            np.array([{"bar": "bar"}, {"bar": "baz"}]),
+            None,
+            [
+                {"bar": "bar", "env": "test"},
+                {"bar": "baz", "env": "test"},
+            ],
+        ),
+        (
+            None,
+            pd.Series(["bar", "baz"], name="bar"),
+            None,
+            [
+                {"bar": "bar", "env": "test"},
+                {"bar": "baz", "env": "test"},
+            ],
+        ),
+        (
+            None,
+            pd.DataFrame({"bar": ["bar", "baz"]}),
+            None,
+            [
+                {"bar": "bar", "env": "test"},
+                {"bar": "baz", "env": "test"},
+            ],
+        ),
     ],
 )
 @mock.patch("gantry.logger.client._resolve_join_keys")
@@ -1882,6 +1954,42 @@ def test_log_records_preds_only(
                 {"bar": "bar", "env": "foobar", "baz": "baz"},
             ],
         ),
+        (
+            None,
+            [{"bar": "bar"}, {"bar": "baz"}],
+            None,
+            [
+                {"bar": "bar", "env": "test"},
+                {"bar": "baz", "env": "test"},
+            ],
+        ),
+        (
+            None,
+            np.array([{"bar": "bar"}, {"bar": "baz"}]),
+            None,
+            [
+                {"bar": "bar", "env": "test"},
+                {"bar": "baz", "env": "test"},
+            ],
+        ),
+        (
+            None,
+            pd.Series(["bar", "baz"], name="bar"),
+            None,
+            [
+                {"bar": "bar", "env": "test"},
+                {"bar": "baz", "env": "test"},
+            ],
+        ),
+        (
+            None,
+            pd.DataFrame({"bar": ["bar", "baz"]}),
+            None,
+            [
+                {"bar": "bar", "env": "test"},
+                {"bar": "baz", "env": "test"},
+            ],
+        ),
     ],
 )
 @mock.patch("gantry.logger.client._resolve_join_keys", return_value=["12345", "54321"])
